==> LEPL-4.0.2.zip: LEPL-4.0.2/src/lepl/_example/operators.py <==

# The contents of this file are subject to the Mozilla Public License
# (MPL) Version 1.1 (the "License"); you may not use this file except
# in compliance with the License. You may obtain a copy of the License
# at http://www.mozilla.org/MPL/
#
# Software distributed under the License is distributed on an "AS IS"
# basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See
# the License for the specific language governing rights and
# limitations under the License.
#
# The Original Code is LEPL (http://www.acooke.org/lepl)
# The Initial Developer of the Original Code is Andrew Cooke.
# Portions created by the Initial Developer are Copyright (C) 2009-2010
# Andrew Cooke (andrew@acooke.org). All Rights Reserved.
#
# Alternatively, the contents of this file may be used under the terms
# of the LGPL license (the GNU Lesser General Public License,
# http://www.gnu.org/licenses/lgpl.html), in which case the provisions
# of the LGPL License are applicable instead of those above.
#
# If you wish to allow use of your version of this file only under the
# terms of the LGPL License and not to allow others to use your version
# of this file under the MPL, indicate your decision by deleting the
# provisions above and replace them with the notice and other provisions
# required by the LGPL License.  If you do not delete the provisions
# above, a recipient may use your version of this file under either the
# MPL or the LGPL License.

# pylint: disable-msg=W0401,C0111,W0614,W0622,C0301,C0321,C0324,C0103
#@PydevCodeAnalysisIgnore
# (the code style is for documentation, not "real")

'''
Examples from the documentation.
'''

from lepl import *
from lepl._example.support import Example


class OperatorExamples(Example):
    
    def test_errors(self):
        self.examples([(lambda: eval("('Mr' | 'Ms') // Word()"),
                        "TypeError: unsupported operand type(s) for |: 'str' and 'str'\n"),
                       (lambda: eval("('Mr' // Word() > 'man' | 'Ms' // Word() > 'woman')"),
                        '''  File "<string>", line None
SyntaxError: The operator > for And('Mr', Transform, Transform) was applied to a matcher (Or('man', And)). Check syntax and parentheses.\n''')])

    def test_override(self):
        
        abcd = None
        with Override(or_=And, and_=Or):
            abcd = (Literal('a') & Literal('b')) | ( Literal('c') & Literal('d'))
        
        self.examples([(lambda: abcd.parse('ac'), "['a', 'c']"),
                       (lambda: abcd.parse('ab'), 
                        "lepl.stream.maxdepth.FullFirstMatchException: The match failed at 'b',\nLine 1, character 1 of str: 'ab'.\n")])
            
        sentence = None
        word = Letter()[:,...]
        with Separator(r'\s+'):
            sentence = word[1:]
            
        self.examples([(lambda: sentence.parse_string('hello world'), 
                        "['hello', ' ', 'world']")])

==> LEPL-4.2.3.zip: LEPL-4.2.3/src/lepl/_example/operators.py <==

# The contents of this file are subject to the Mozilla Public License
# (MPL) Version 1.1 (the "License"); you may not use this file except
# in compliance with the License. You may obtain a copy of the License
# at http://www.mozilla.org/MPL/
#
# Software distributed under the License is distributed on an "AS IS"
# basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See
# the License for the specific language governing rights and
# limitations under the License.
#
# The Original Code is LEPL (http://www.acooke.org/lepl)
# The Initial Developer of the Original Code is Andrew Cooke.
# Portions created by the Initial Developer are Copyright (C) 2009-2010
# Andrew Cooke (andrew@acooke.org). All Rights Reserved.
#
# Alternatively, the contents of this file may be used under the terms
# of the LGPL license (the GNU Lesser General Public License,
# http://www.gnu.org/licenses/lgpl.html), in which case the provisions
# of the LGPL License are applicable instead of those above.
#
# If you wish to allow use of your version of this file only under the
# terms of the LGPL License and not to allow others to use your version
# of this file under the MPL, indicate your decision by deleting the
# provisions above and replace them with the notice and other provisions
# required by the LGPL License.  If you do not delete the provisions
# above, a recipient may use your version of this file under either the
# MPL or the LGPL License.

# pylint: disable-msg=W0401,C0111,W0614,W0622,C0301,C0321,C0324,C0103
#@PydevCodeAnalysisIgnore
# (the code style is for documentation, not "real")

'''
Examples from the documentation.
'''

from lepl import *
from lepl._example.support import Example


class OperatorExamples(Example):
    
    def test_errors(self):
        self.examples([(lambda: eval("('Mr' | 'Ms') // Word()"),
                        "TypeError: unsupported operand type(s) for |: 'str' and 'str'\n"),
                       (lambda: eval("('Mr' // Word() > 'man' | 'Ms' // Word() > 'woman')"),
                        '''  File "<string>", line None
SyntaxError: The operator > for And(Literal, Transform, Transform) was applied to a matcher (Or(Literal, And)). Check syntax and parentheses.\n''')])

    def test_override(self):
        
        abcd = None
        with Override(or_=And, and_=Or):
            abcd = (Literal('a') & Literal('b')) | ( Literal('c') & Literal('d'))
        
        self.examples([(lambda: abcd.parse('ac'), "['a', 'c']"),
                       (lambda: abcd.parse('ab'), 
                        "lepl.stream.maxdepth.FullFirstMatchException: The match failed at 'b',\nLine 1, character 1 of str: 'ab'.\n")])
            
        sentence = None
        word = Letter()[:,...]
        with Separator(r'\s+'):
            sentence = word[1:]
            
        self.examples([(lambda: sentence.parse_string('hello world'), 
                        "['hello', ' ', 'world']")])
